syncmap

package
v0.0.0-...-63027bd Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2025 License: AGPL-3.0 Imports: 1 Imported by: 2

Documentation

Overview

Sourced from https://www.reddit.com/r/golang/comments/twucb0/is_there_already_a_generic_threadsafe_map/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Map

type Map[K comparable, V any] struct {
	// contains filtered or unexported fields
}

func (*Map[K, V]) Delete

func (m *Map[K, V]) Delete(key K)

Delete deletes the value for a key.

func (*Map[K, V]) Load

func (m *Map[K, V]) Load(key K) (value V, ok bool)

Load returns the value stored in the map for a key, or nil if no value is present. The ok result indicates whether value was found in the map.

func (*Map[K, V]) LoadAndDelete

func (m *Map[K, V]) LoadAndDelete(key K) (value V, loaded bool)

LoadAndDelete deletes the value for a key, returning the previous value if any. The loaded result reports whether the key was present.

func (*Map[K, V]) LoadOrStore

func (m *Map[K, V]) LoadOrStore(key K, value V) (actual V, loaded bool)

LoadOrStore returns the existing value for the key if present. Otherwise, it stores and returns the given value. The loaded result is true if the value was loaded, false if stored.

func (*Map[K, V]) Range

func (m *Map[K, V]) Range(f func(key K, value V) bool)

Range calls f sequentially for each key and value present in the map. If f returns false, range stops the iteration.

Range does not necessarily correspond to any consistent snapshot of the Map's contents: no key will be visited more than once, but if the value for any key is stored or deleted concurrently (including by f), Range may reflect any mapping for that key from any point during the Range call. Range does not block other methods on the receiver; even f itself may call any method on m.

Range may be O(N) with the number of elements in the map even if f returns false after a constant number of calls.

func (*Map[K, V]) RealLength

func (m *Map[K, V]) RealLength() int

RealLength returns the number of items in the map by counting the number of elements in the map

This is an extension to the sync.Map type.

func (*Map[K, V]) Store

func (m *Map[K, V]) Store(key K, value V)

Store sets the value for a key.

type MutexedMap

type MutexedMap[K comparable, V any] struct {
	sync.RWMutex
	Map map[K]V
}

func (*MutexedMap[K, V]) Delete

func (m *MutexedMap[K, V]) Delete(key K)

func (*MutexedMap[K, V]) Length

func (m *MutexedMap[K, V]) Length() int

func (*MutexedMap[K, V]) Load

func (m *MutexedMap[K, V]) Load(key K) (V, bool)

func (*MutexedMap[K, V]) Store

func (m *MutexedMap[K, V]) Store(key K, val V)

Jump to